@@ -6,7 +6,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.59
+0.60
 
 =head1 SYNOPSIS
 
@@ -140,7 +140,7 @@ use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || $ENV{SWAGGER2_DEBUG} || 0;
 use constant WARN_ON_MISSING_FORMAT => $ENV{JSON_VALIDATOR_WARN_ON_MISSING_FORMAT}
   || $ENV{SWAGGER2_WARN_ON_MISSING_FORMAT} ? 1 : 0;
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 our @EXPORT_OK = qw( validate_json );
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -524,6 +524,11 @@ sub _validate {
   my $type = $schema->{type} || _guess_schema_type($schema, $data);
   my @errors;
 
+  # Make sure we validate plain data and not a perl object
+  if (UNIVERSAL::can($data, 'TO_JSON')) {
+    $data = $data->TO_JSON;
+  }
+
   # Test base schema before allOf, anyOf or oneOf
   if (ref $type eq 'ARRAY') {
     for my $type (@$type) {
